//sicherstellen, dass die Headerdatei nur einmal eingebunden wird...
#ifndef __PRKMPT1_H
#define __PRKMPT1_H

/******************************************************************************
 *          --- int tr_message ---                                            *
 *  Nachricht (Funktionscode und Daten) zum Controller uebertragen            *
 *                                                                            *
 *  Parameter:  int fun           - Funktionscode (Nachricht)                 *
 *              int rd            - Portnummer des Datenregisters             *
 *              int rs            - Portnummer des Steuerregisters            *
 *              unsigned char *p  - Zeiger auf Datenpuffer                    *
 *              int l             - Anzahl der zu uebertragenden Bytes        *
 *                                                                            *
 *  Rueckgabewert:  0   - OK                                                  *
 *                 -1   - FEHLER                                              *
 *                 -2   - Controller kann die angeforderte Funktion zu diesem *
 *                        Zeitpunkt nicht ausfuehren                          *
 *                        oder unbekannter Funktionscode                      * 
 *                 -3   - Checksummenfehler                                   *
 ******************************************************************************/
int tr_message(int fun, int rd, int rs, unsigned char *p, int l);


/******************************************************************************
 *          --- int rc_message ---                                            *
 *  Nachricht vom Controller empfangen                                        *
 *  (Funktionscode dem Controller uebermitteln und Ergebnisdaten empfangen)   *
 *                                                                            *
 *  Parameter:  int fun           - Funktionscode (Nachricht)                 *
 *              int rd            - Portnummer des Datenregisters             *
 *              int rs            - Portnummer des Statusregisters            *
 *              unsigned char *p  - Zeiger auf Datenpuffer                    *
 *              int ml            - max. Laenge der zu empfangenden Daten     *
 *              int *l            - Zeiger auf Anzahl der empfangenen Daten   *
 *                                                                            *
 *  Bemerkung: Der Wert von *l beim Funktionsaufruf ist unerheblich, da *l    *
 *             im Verlauf der Funktion mit der tatsaechlichen Anzahl der      *
 *             empfangenen Byte ueberschrieben wird.                          *
 *                                                                            *
 *  Rueckgabewert:  0   - OK                                                  *
 *                 -1   - FEHLER                                              *
 *                 -2   - Controller kann die angeforderte Funktion zu diesem *
 *                        Zeitpunkt nicht ausfuehren                          *
 *                        oder unbekannter Funktionscode                      *
 *                 -3   - Checksummenfehler                                   *
 *                 -4   - Daten stehen nicht bereit                           *
 ******************************************************************************/
int rc_message(int fun, int rd, int rs, unsigned char *p, int ml, int *l);


/******************************************************************************
 *           --- int out_byte ---                                             *
 *  Datenbyte zum Controller uebertragen                                      *
 *                                                                            *
 *  Parameter:  int rd  - Portnummer des Datenregisters                       *
 *              int rs  - Portnummer des Steuerregisters                      *
 *              int d   - Datenpuffer (1 Integer)                             *
 *                                                                            *
 *  Rueckgabewert:    0 - OK                                                  *
 *                   -1 - FEHLER                                              *
 ******************************************************************************/
int out_byte(int rd, int rs, int d);


/******************************************************************************
 *            --- int in_byte ---                                             *
 *  Datenbyte vom Controller empfangen                                        *
 *                                                                            *
 *  Parameter:  int rd  - Portnummer des Datenregisters                       *
 *              int rs  - Portnummer des Steuerregisters                      *
 *              int d   - Zeiger auf Datenpuffer (1 Integer)                  *
 *                                                                            *
 *  Rueckgabewert:   0   - OK                                                 *
 *                  -1   - FEHLER                                             *
 ******************************************************************************/
int in_byte(int rd, int rs, int *d);


/******************************************************************************
 *           --- int status_rd ---                                            *
 *  Testen ob Controller zur Datenuebergabe (senden) bereit                   *
 *                                                                            *
 *  Parameter:  int rs  - Portnummer des Steuerregisters                      *
 *                                                                            *
 *  Rueckgabewert:  0   - Controller nicht breit (Datenregister leer)         *
 *                  !0  - Controller bereit (Datenregister nicht leer)        *
 ******************************************************************************/
int status_rd(int rs);


/******************************************************************************
 *           --- int status_wr ---                                            *
 *  Testen ob Controller zur Datenuebernahme (empfangen) bereit               *
 *                                                                            *
 *  Parameter:  int rs  - Portnummer des Steuerregisters                      *
 *                                                                            *
 *  Rueckgabewert: 0   - Controller bereit (Datenregister leer)               *
 *                 !0  - Controller nicht bereit (Datenregister nicht leer)   *
 ******************************************************************************/
int status_wr(int rs);


/******************************************************************************
 *            --- int crnt_time ---                                           *
 *  Zeit seit dem Start des Systems in Millisekunden ermitteln                *
 *                                                                            *
 *  Rueckgabewert:  int - ???                                                 *
 ******************************************************************************/
int crnt_time(void);

#endif /* define __PKRMPT1_H */